@@ -2,17 +2,19 @@ package RT::Extension::QuickUpdate;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '1.00';
 
 1;
+
 =head1 NAME
 
 RT::Extension::QuickUpdate - Adds an update box to ticket display
 
 =head1 DESCRIPTION
 
-[Why would someone install this extension? What does it do? What problem
-does it solve?]
+This adds an update box to the ticket display page allowing one to quickly
+change: i) status; ii) owner; iii) priority; and iv) queue; instead of
+needing to browse between tabs in order to do so.
 
 =head1 RT VERSION
 
